@@ -1,4 +1,5 @@
 import os
+import sys
 import weakref
 import pytest
 from pytestqt.qt_compat import qt_api
@@ -324,13 +325,15 @@ def test_parse_ini_boolean_invalid():
         pytestqt.qtbot._parse_ini_boolean('foo')
 
 
-@pytest.mark.parametrize('option_api', ['pyqt4', 'pyqt5', 'pyside'])
-def test_qt_api_ini_config(testdir, option_api):
+@pytest.mark.parametrize('option_api', ['pyqt4', 'pyqt5', 'pyside', 'pyside2'])
+def test_qt_api_ini_config(testdir, monkeypatch, option_api):
     """
     Test qt_api ini option handling.
     """
     from pytestqt.qt_compat import qt_api
 
+    monkeypatch.delenv("PYTEST_QT_API")
+
     testdir.makeini("""
         [pytest]
         qt_api={option_api}
@@ -344,7 +347,45 @@ def test_qt_api_ini_config(testdir, option_api):
     ''')
 
     result = testdir.runpytest_subprocess()
-    if qt_api.pytest_qt_api.startswith(option_api):  # handle pyqt4v2
+    if qt_api.pytest_qt_api.replace('v2', '') == option_api:  # handle pyqt4v2
+        result.stdout.fnmatch_lines([
+            '* 1 passed in *'
+        ])
+    else:
+        try:
+            ModuleNotFoundError
+        except NameError:
+            # Python < 3.6
+            result.stderr.fnmatch_lines([
+                '*ImportError:*'
+            ])
+        else:
+            # Python >= 3.6
+            result.stderr.fnmatch_lines([
+                '*ModuleNotFoundError:*'
+            ])
+
+
+@pytest.mark.parametrize('envvar', ['pyqt4', 'pyqt5', 'pyside', 'pyside2'])
+def test_qt_api_ini_config_with_envvar(testdir, monkeypatch, envvar):
+    """ensure environment variable wins over config value if both are present
+    """
+    testdir.makeini("""
+        [pytest]
+        qt_api={option_api}
+    """.format(option_api='piecute'))
+
+    monkeypatch.setenv('PYTEST_QT_API', envvar)
+
+    testdir.makepyfile('''
+        import pytest
+
+        def test_foo(qtbot):
+            pass
+    ''')
+
+    result = testdir.runpytest_subprocess()
+    if qt_api.pytest_qt_api.replace('v2', '') == envvar:
         result.stdout.fnmatch_lines([
             '* 1 passed in *'
         ])
@@ -376,3 +417,28 @@ def test_invalid_qt_api_envvar(testdir, monkeypatch):
     monkeypatch.setenv('PYTEST_QT_API', 'piecute')
     result = testdir.runpytest_subprocess()
     result.stderr.fnmatch_lines(['* Invalid value for $PYTEST_QT_API: piecute'])
+
+
+@pytest.mark.skipif(qt_api.pytest_qt_api in ['pyqt4', 'pyqt4v2', 'pyside'],
+                    reason="QApplication.arguments() doesn't return custom arguments with Qt4 and Windows")
+def test_qapp_args(testdir):
+    """
+    Test customizing of QApplication arguments.
+    """
+    testdir.makeconftest(
+        '''
+        import pytest
+
+        @pytest.fixture(scope='session')
+        def qapp_args():
+            return ['--test-arg']
+        '''
+    )
+    testdir.makepyfile('''
+        def test_args(qapp):
+            assert '--test-arg' in list(qapp.arguments())
+    ''')
+    result = testdir.runpytest_subprocess()
+    result.stdout.fnmatch_lines([
+        '*= 1 passed in *'
+    ])
