@@ -4,7 +4,7 @@ import pytest
 from pytestqt.qt_compat import qt_api
 
 
-fails_on_pyqt = pytest.mark.xfail('qt_api.pytest_qt_api != "pyside"')
+fails_on_pyqt = pytest.mark.xfail('not qt_api.pytest_qt_api.startswith("pyside")')
 
 
 @pytest.mark.parametrize('expected_method', [
@@ -29,4 +29,4 @@ def test_expected_qtest_proxies(qtbot, expected_method):
     Ensure that we are exporting expected QTest API methods.
     """
     assert hasattr(qtbot, expected_method)
-    assert getattr(qtbot, expected_method).__name__ == expected_method
\ No newline at end of file
+    assert getattr(qtbot, expected_method).__name__ == expected_method
